pub enum RevocationReason {
Unknown,
Manual,
TwoFactorPolicyNonCompliance,
OrganizationDataOwnershipPolicyNonCompliance,
SingleOrgPolicyNonCompliance,
__Unknown(i64),
}Expand description
RevocationReason : The reason a user was revoked from an organization. The reason a user was revoked from an organization.
Variants
Unknown
Manual
TwoFactorPolicyNonCompliance
OrganizationDataOwnershipPolicyNonCompliance
SingleOrgPolicyNonCompliance
__Unknown(i64)
Unknown value returned from the server. This is used to handle forward compatibility.
Implementations